@@ -1222,12 +1222,6 @@ get_child_environment (TerminalScreen *screen,
    */
   g_hash_table_remove (env_table, "WINDOWID");
 
-  /* We need to put the working directory also in PWD, so that
-   * e.g. bash starts in the right directory if @cwd is a symlink.
-   * See bug #502146.
-   */
-  g_hash_table_replace (env_table, g_strdup ("PWD"), g_strdup (cwd));
-
   terminal_util_add_proxy_env (env_table);
 
   /* Add gnome-terminal private env vars used to communicate back to g-t-server */
