@@ -270,9 +270,25 @@ terminal_settings_list_ref_child_internal (TerminalSettingsList *list,
   return g_object_ref (child);
 }
 
+static char *
+new_child (TerminalSettingsList *list,
+           const char *name)
+{
+  char *new_uuid = new_list_entry ();
+
+  if (name != NULL) {
+    gs_free char *new_path = path_new (list, new_uuid);
+    gs_unref_object GSettings *child = g_settings_new_with_path (list->child_schema_id, new_path);
+    g_settings_set_string (child, TERMINAL_PROFILE_VISIBLE_NAME_KEY, name);
+  }
+
+  return new_uuid;
+}
+
 static char *
 clone_child (TerminalSettingsList *list,
-             const char *uuid)
+             const char *uuid,
+             const char *name)
 {
   char *new_uuid;
   gs_free char *path;
@@ -305,7 +321,6 @@ clone_child (TerminalSettingsList *list,
 
     rkey = g_strconcat (path, keys[i], NULL);
     value = dconf_client_read (client, rkey);
-
     if (value) {
       gs_free char *wkey;
       wkey = g_strconcat (new_path, keys[i], NULL);
@@ -313,6 +328,16 @@ clone_child (TerminalSettingsList *list,
     }
   }
 
+  if (name != NULL) {
+    GVariant *value;
+    value = g_variant_new_string (name);
+    if (value) {
+      gs_free char *wkey;
+      wkey = g_strconcat (new_path, TERMINAL_PROFILE_VISIBLE_NAME_KEY, NULL);
+      dconf_changeset_set (changeset, wkey, value);
+    }
+  }
+
   dconf_client_change_sync (client, changeset, NULL, NULL, NULL);
   dconf_changeset_unref (changeset);
 
@@ -321,15 +346,16 @@ clone_child (TerminalSettingsList *list,
 
 static char *
 terminal_settings_list_add_child_internal (TerminalSettingsList *list,
-                                           const char *uuid)
+                                           const char *uuid,
+                                           const char *name)
 {
   char *new_uuid;
   gs_strfreev char **new_uuids;
 
   if (uuid && settings_backend_is_dconf ())
-    new_uuid = clone_child (list, uuid);
+    new_uuid = clone_child (list, uuid, name);
   else
-    new_uuid = new_list_entry ();
+    new_uuid = new_child (list, name);
 
   _terminal_debug_print (TERMINAL_DEBUG_SETTINGS_LIST,
                          "%s NEW UUID %s\n", G_STRFUNC, new_uuid);
@@ -762,23 +788,26 @@ terminal_settings_list_ref_default_child (TerminalSettingsList *list)
 /**
  * terminal_settings_list_add_child:
  * @list: a #TerminalSettingsList
+ * @name: the name of the new profile
  *
  * Adds a new child to the list, and returns a reference to its #GSettings.
  *
  * Returns: (transfer full): the UUID of new child
  */
 char *
-terminal_settings_list_add_child (TerminalSettingsList *list)
+terminal_settings_list_add_child (TerminalSettingsList *list,
+                                  const char *name)
 {
   g_return_val_if_fail (TERMINAL_IS_SETTINGS_LIST (list), NULL);
 
-  return terminal_settings_list_add_child_internal (list, NULL);
+  return terminal_settings_list_add_child_internal (list, NULL, name);
 }
 
 /**
  * terminal_settings_list_clone_child:
  * @list: a #TerminalSettingsList
  * @uuid: the UUID of the child to clone
+ * @name: the name of the new child
  *
  * Adds a new child to the list, and returns a reference to its #GSettings.
  * All keys of the new child will have the same value as @uuid's.
@@ -787,12 +816,13 @@ terminal_settings_list_add_child (TerminalSettingsList *list)
  */
 char *
 terminal_settings_list_clone_child (TerminalSettingsList *list,
-                                    const char *uuid)
+                                    const char *uuid,
+                                    const char *name)
 {
   g_return_val_if_fail (TERMINAL_IS_SETTINGS_LIST (list), NULL);
   g_return_val_if_fail (terminal_settings_list_valid_uuid (uuid), NULL);
 
-  return terminal_settings_list_add_child_internal (list, uuid);
+  return terminal_settings_list_add_child_internal (list, uuid, name);
 }
 
 /**
