@@ -162,7 +162,8 @@ terminal_util_show_about (void)
     "Copyright © 2002–2004 Havoc Pennington\n"
     "Copyright © 2003–2004, 2007 Mariano Suárez-Alvarez\n"
     "Copyright © 2006 Guilherme de S. Pastore\n"
-    "Copyright © 2007–2017 Christian Persch";
+    "Copyright © 2007–2018 Christian Persch\n"
+    "Copyright © 2013–2018 Egmont Koblinger";
   char *licence_text;
   GKeyFile *key_file;
   GBytes *bytes;
@@ -407,13 +408,13 @@ main_object_destroy_cb (GtkWidget *widget)
   g_object_set_data (G_OBJECT (widget), "builder", NULL);
 }
 
-void
+GtkBuilder *
 terminal_util_load_widgets_resource (const char *path,
                                      const char *main_object_name,
                                      const char *object_name,
                                      ...)
 {
-  gs_unref_object GtkBuilder *builder;
+  GtkBuilder *builder;
   GError *error = NULL;
   va_list args;
 
@@ -453,6 +454,7 @@ terminal_util_load_widgets_resource (const char *path,
       gtk_widget_set_margin_bottom (action_area, 5);
     }
   }
+  return builder;
 }
 
 void
@@ -494,16 +496,14 @@ terminal_util_dialog_response_on_delete (GtkWindow *widget)
 }
 
 void
-terminal_util_dialog_focus_widget (GtkWidget *dialog,
+terminal_util_dialog_focus_widget (GtkBuilder *builder,
                                    const char *widget_name)
 {
-  GtkBuilder *builder;
   GtkWidget *widget, *page, *page_parent;
 
   if (widget_name == NULL)
     return;
 
-  builder = g_object_get_data (G_OBJECT (dialog), "builder");
   widget = GTK_WIDGET (gtk_builder_get_object (builder, widget_name));
   if (widget == NULL)
     return;
